@@ -30,7 +30,7 @@ class DatabaseBackend implements CacheBackendInterface {
   const DEFAULT_MAX_ROWS = 5000;
 
   /**
-   * -1 means infinite allows numbers of rows for the cache backend.
+   * Indicates that an infinite number of rows is allowed for the cache backend.
    */
   const MAXIMUM_NONE = -1;
 
@@ -42,9 +42,9 @@ class DatabaseBackend implements CacheBackendInterface {
   /**
    * The maximum number of rows that this cache bin table is allowed to store.
    *
-   * @see ::MAXIMUM_NONE
-   *
    * @var int
+   *
+   * @see ::MAXIMUM_NONE
    */
   protected $maxRows;
 
@@ -128,11 +128,23 @@ class DatabaseBackend implements CacheBackendInterface {
     // ::select() is a much smaller proportion of the request.
     $result = [];
     try {
-      $result = $this->connection->query('SELECT [cid], [data], [created], [expire], [serialized], [tags], [checksum] FROM {' . $this->connection->escapeTable($this->bin) . '} WHERE [cid] IN ( :cids[] ) ORDER BY [cid]', [':cids[]' => array_keys($cid_mapping)]);
+      $result = $this->connection->query('SELECT [cid], [data], [created], [expire], [serialized], [tags], [checksum] FROM {' . $this->connection->escapeTable($this->bin) . '} WHERE [cid] IN ( :cids[] ) ORDER BY [cid]', [':cids[]' => array_keys($cid_mapping)])->fetchAll();
     }
-    catch (\Exception $e) {
+    catch (\Exception) {
       // Nothing to do.
     }
+    // Before checking the validity of each item individually, register the
+    // cache tags for all returned cache items for preloading, this allows the
+    // cache tag service to optimize cache tag lookups.
+    if ($this->checksumProvider instanceof CacheTagsChecksumPreloadInterface) {
+      $tags_for_preload = [];
+      foreach ($result as $item) {
+        if ($item->tags) {
+          $tags_for_preload[] = explode(' ', $item->tags);
+        }
+      }
+      $this->checksumProvider->registerCacheTagsForPreload(array_merge(...$tags_for_preload));
+    }
     $cache = [];
     foreach ($result as $item) {
       // Map the cache ID back to the original.
@@ -375,6 +387,7 @@ class DatabaseBackend implements CacheBackendInterface {
    * {@inheritdoc}
    */
   public function invalidateAll() {
+    @trigger_error("CacheBackendInterface::invalidateAll() is deprecated in drupal:11.2.0 and is removed from drupal:12.0.0. Use CacheBackendInterface::deleteAll() or cache tag invalidation instead. See https://www.drupal.org/node/3500622", E_USER_DEPRECATED);
     try {
       $this->connection->update($this->bin)
         ->fields(['expire' => $this->time->getRequestTime() - 1])
@@ -411,7 +424,7 @@ class DatabaseBackend implements CacheBackendInterface {
         ->condition('expire', $this->time->getRequestTime(), '<')
         ->execute();
     }
-    catch (\Exception $e) {
+    catch (\Exception) {
       // If the table does not exist, it surely does not have garbage in it.
       // If the table exists, the next garbage collection will clean up.
       // There is nothing to do.
@@ -445,7 +458,7 @@ class DatabaseBackend implements CacheBackendInterface {
     // If another process has already created the cache table, attempting to
     // recreate it will throw an exception. In this case just catch the
     // exception and do nothing.
-    catch (DatabaseException $e) {
+    catch (DatabaseException) {
       return TRUE;
     }
     return FALSE;
@@ -458,7 +471,7 @@ class DatabaseBackend implements CacheBackendInterface {
    * yet the query failed, then the cache is stale and the exception needs to
    * propagate.
    *
-   * @param $e
+   * @param \Exception $e
    *   The exception.
    * @param string|null $table_name
    *   The table name. Defaults to $this->bin.
@@ -566,9 +579,10 @@ class DatabaseBackend implements CacheBackendInterface {
   }
 
   /**
-   * The maximum number of rows that this cache bin table is allowed to store.
+   * Gets the maximum number of rows for this cache bin table.
    *
    * @return int
+   *   The maximum number of rows that this cache bin table is allowed to store.
    */
   public function getMaxRows() {
     return $this->maxRows;
