@@ -373,6 +373,7 @@ abstract class EntityDisplayBase extends ConfigEntityBase implements EntityDispl
   /**
    * {@inheritdoc}
    */
+  #[ActionMethod(adminLabel: new TranslatableMarkup('Hide component'), name: 'hideComponent')]
   public function removeComponent($name) {
     $this->hidden[$name] = TRUE;
     unset($this->content[$name]);
@@ -395,7 +396,13 @@ abstract class EntityDisplayBase extends ConfigEntityBase implements EntityDispl
     }
 
     // Let other modules feedback about their own additions.
-    $weights = array_merge($weights, \Drupal::moduleHandler()->invokeAll('field_info_max_weight', [$this->targetEntityType, $this->bundle, $this->displayContext, $this->mode]));
+    $weights = array_merge($weights,
+      \Drupal::moduleHandler()->invokeAll('field_info_max_weight', [
+        $this->targetEntityType,
+        $this->bundle,
+        $this->displayContext,
+        $this->mode,
+      ]));
 
     return $weights ? max($weights) : NULL;
   }
@@ -432,6 +439,10 @@ abstract class EntityDisplayBase extends ConfigEntityBase implements EntityDispl
    *   A field definition.
    *
    * @return array|null
+   *   The array of display options for the field, or NULL if the field is not
+   *   displayed.
+   *
+   * @see \Drupal\Core\Field\FieldDefinitionInterface::getDisplayOptions
    */
   private function fieldHasDisplayOptions(FieldDefinitionInterface $definition) {
     // The display only cares about fields that specify display options.
@@ -587,4 +598,20 @@ abstract class EntityDisplayBase extends ConfigEntityBase implements EntityDispl
     return \Drupal::logger('system');
   }
 
+  /**
+   * {@inheritdoc}
+   */
+  public function set($property_name, $value): static {
+    // If changing the entity ID, also update the target entity type, bundle,
+    // and view mode.
+    if ($this->isNew() && $property_name === $this->getEntityType()->getKey('id')) {
+      if (substr_count($value, '.') !== 2) {
+        throw new \InvalidArgumentException("'$value' is not a valid entity display ID.");
+      }
+      [$this->targetEntityType, $this->bundle, $this->mode] = explode('.', $value);
+    }
+    parent::set($property_name, $value);
+    return $this;
+  }
+
 }
