@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\system\Functional\Entity\Traits;
 
 use Drupal\Core\Entity\EntityDefinitionUpdateManagerInterface;
@@ -22,7 +24,7 @@ trait EntityDefinitionTestTrait {
    *   (optional) Applies changes only for the specified entity type ID.
    *   Defaults to NULL.
    */
-  protected function applyEntityUpdates($entity_type_id = NULL) {
+  protected function applyEntityUpdates($entity_type_id = NULL): void {
     $complete_change_list = \Drupal::entityDefinitionUpdateManager()->getChangeList();
     if ($complete_change_list) {
       // In case there are changes, explicitly invalidate caches.
@@ -49,8 +51,8 @@ trait EntityDefinitionTestTrait {
         $original_storage_definitions = \Drupal::service('entity.last_installed_schema.repository')->getLastInstalledFieldStorageDefinitions($entity_type_id);
 
         foreach ($change_list['field_storage_definitions'] as $field_name => $change) {
-          $storage_definition = isset($storage_definitions[$field_name]) ? $storage_definitions[$field_name] : NULL;
-          $original_storage_definition = isset($original_storage_definitions[$field_name]) ? $original_storage_definitions[$field_name] : NULL;
+          $storage_definition = $storage_definitions[$field_name] ?? NULL;
+          $original_storage_definition = $original_storage_definitions[$field_name] ?? NULL;
           $this->doFieldUpdate($change, $storage_definition, $original_storage_definition);
         }
       }
@@ -66,7 +68,7 @@ trait EntityDefinitionTestTrait {
    * @param string $entity_type_id
    *   The entity type ID.
    */
-  protected function doEntityUpdate($op, $entity_type_id) {
+  protected function doEntityUpdate($op, $entity_type_id): void {
     $entity_type = \Drupal::entityTypeManager()->getDefinition($entity_type_id);
     $field_storage_definitions = \Drupal::service('entity_field.manager')->getFieldStorageDefinitions($entity_type_id);
     switch ($op) {
@@ -94,7 +96,7 @@ trait EntityDefinitionTestTrait {
    * @param array|null $original_storage_definition
    *   The original field storage definition.
    */
-  protected function doFieldUpdate($op, $storage_definition = NULL, $original_storage_definition = NULL) {
+  protected function doFieldUpdate($op, $storage_definition = NULL, $original_storage_definition = NULL): void {
     switch ($op) {
       case EntityDefinitionUpdateManagerInterface::DEFINITION_CREATED:
         \Drupal::service('field_storage_definition.listener')->onFieldStorageDefinitionCreate($storage_definition);
@@ -113,7 +115,7 @@ trait EntityDefinitionTestTrait {
   /**
    * Enables a new entity type definition.
    */
-  protected function enableNewEntityType() {
+  protected function enableNewEntityType(): void {
     $this->state->set('entity_test_new', TRUE);
     $this->applyEntityUpdates('entity_test_new');
   }
@@ -121,7 +123,7 @@ trait EntityDefinitionTestTrait {
   /**
    * Resets the entity type definition.
    */
-  protected function resetEntityType() {
+  protected function resetEntityType(): void {
     $updated_entity_type = $this->getUpdatedEntityTypeDefinition(FALSE, FALSE);
     $updated_field_storage_definitions = $this->getUpdatedFieldStorageDefinitions(FALSE, FALSE);
     $this->entityDefinitionUpdateManager->updateFieldableEntityType($updated_entity_type, $updated_field_storage_definitions);
@@ -134,7 +136,7 @@ trait EntityDefinitionTestTrait {
    *   (optional) Whether the change should be performed by the entity
    *   definition update manager.
    */
-  protected function updateEntityTypeToRevisionable($perform_update = FALSE) {
+  protected function updateEntityTypeToRevisionable($perform_update = FALSE): void {
     $translatable = $this->entityDefinitionUpdateManager->getEntityType('entity_test_update')->isTranslatable();
 
     $updated_entity_type = $this->getUpdatedEntityTypeDefinition(TRUE, $translatable);
@@ -152,7 +154,7 @@ trait EntityDefinitionTestTrait {
    *   (optional) Whether the change should be performed by the entity
    *   definition update manager.
    */
-  protected function updateEntityTypeToNotRevisionable($perform_update = FALSE) {
+  protected function updateEntityTypeToNotRevisionable($perform_update = FALSE): void {
     $translatable = $this->entityDefinitionUpdateManager->getEntityType('entity_test_update')->isTranslatable();
 
     $updated_entity_type = $this->getUpdatedEntityTypeDefinition(FALSE, $translatable);
@@ -170,7 +172,7 @@ trait EntityDefinitionTestTrait {
    *   (optional) Whether the change should be performed by the entity
    *   definition update manager.
    */
-  protected function updateEntityTypeToTranslatable($perform_update = FALSE) {
+  protected function updateEntityTypeToTranslatable($perform_update = FALSE): void {
     $revisionable = $this->entityDefinitionUpdateManager->getEntityType('entity_test_update')->isRevisionable();
 
     $updated_entity_type = $this->getUpdatedEntityTypeDefinition($revisionable, TRUE);
@@ -188,7 +190,7 @@ trait EntityDefinitionTestTrait {
    *   (optional) Whether the change should be performed by the entity
    *   definition update manager.
    */
-  protected function updateEntityTypeToNotTranslatable($perform_update = FALSE) {
+  protected function updateEntityTypeToNotTranslatable($perform_update = FALSE): void {
     $revisionable = $this->entityDefinitionUpdateManager->getEntityType('entity_test_update')->isRevisionable();
 
     $updated_entity_type = $this->getUpdatedEntityTypeDefinition($revisionable, FALSE);
@@ -200,14 +202,13 @@ trait EntityDefinitionTestTrait {
   }
 
   /**
-   * Updates the 'entity_test_update' entity type to revisionable and
-   * translatable.
+   * Updates the test entity type to be revisionable and translatable.
    *
    * @param bool $perform_update
    *   (optional) Whether the change should be performed by the entity
    *   definition update manager.
    */
-  protected function updateEntityTypeToRevisionableAndTranslatable($perform_update = FALSE) {
+  protected function updateEntityTypeToRevisionableAndTranslatable($perform_update = FALSE): void {
     $updated_entity_type = $this->getUpdatedEntityTypeDefinition(TRUE, TRUE);
     $updated_field_storage_definitions = $this->getUpdatedFieldStorageDefinitions(TRUE, TRUE);
 
@@ -227,19 +228,30 @@ trait EntityDefinitionTestTrait {
    * @param bool $is_revisionable
    *   (optional) If the base field should be revisionable or not. Defaults to
    *   FALSE.
+   * @param bool $set_label
+   *   (optional) If the base field should have a label or not. Defaults to
+   *   TRUE.
+   * @param bool $is_translatable
+   *   (optional) If the base field should be translatable or not. Defaults to
+   *   FALSE.
    */
-  protected function addBaseField($type = 'string', $entity_type_id = 'entity_test_update', $is_revisionable = FALSE) {
+  protected function addBaseField($type = 'string', $entity_type_id = 'entity_test_update', $is_revisionable = FALSE, $set_label = TRUE, $is_translatable = FALSE): void {
     $definitions['new_base_field'] = BaseFieldDefinition::create($type)
       ->setName('new_base_field')
       ->setRevisionable($is_revisionable)
-      ->setLabel(t('A new base field'));
+      ->setTranslatable($is_translatable);
+
+    if ($set_label) {
+      $definitions['new_base_field']->setLabel(t('A new base field'));
+    }
+
     $this->state->set($entity_type_id . '.additional_base_field_definitions', $definitions);
   }
 
   /**
    * Adds a long-named base field to the 'entity_test_update' entity type.
    */
-  protected function addLongNameBaseField() {
+  protected function addLongNameBaseField(): void {
     $key = 'entity_test_update.additional_base_field_definitions';
     $definitions = $this->state->get($key, []);
     $definitions['new_long_named_entity_reference_base_field'] = BaseFieldDefinition::create('entity_reference')
@@ -256,7 +268,7 @@ trait EntityDefinitionTestTrait {
    * @param string $type
    *   (optional) The field type for the new field. Defaults to 'string'.
    */
-  protected function addRevisionableBaseField($type = 'string') {
+  protected function addRevisionableBaseField($type = 'string'): void {
     $definitions['new_base_field'] = BaseFieldDefinition::create($type)
       ->setName('new_base_field')
       ->setLabel(t('A new revisionable base field'))
@@ -267,14 +279,14 @@ trait EntityDefinitionTestTrait {
   /**
    * Modifies the new base field from 'string' to 'text'.
    */
-  protected function modifyBaseField() {
+  protected function modifyBaseField(): void {
     $this->addBaseField('text');
   }
 
   /**
    * Promotes a field to an entity key.
    */
-  protected function makeBaseFieldEntityKey() {
+  protected function makeBaseFieldEntityKey(): void {
     $entity_type = clone \Drupal::entityTypeManager()->getDefinition('entity_test_update');
     $entity_keys = $entity_type->getKeys();
     $entity_keys['new_base_field'] = 'new_base_field';
@@ -288,21 +300,21 @@ trait EntityDefinitionTestTrait {
    * @param string $entity_type_id
    *   (optional) The entity type ID the base field should be attached to.
    */
-  protected function removeBaseField($entity_type_id = 'entity_test_update') {
+  protected function removeBaseField($entity_type_id = 'entity_test_update'): void {
     $this->state->delete($entity_type_id . '.additional_base_field_definitions');
   }
 
   /**
    * Adds a single-field index to the base field.
    */
-  protected function addBaseFieldIndex() {
+  protected function addBaseFieldIndex(): void {
     $this->state->set('entity_test_update.additional_field_index.entity_test_update.new_base_field', TRUE);
   }
 
   /**
    * Removes the index added in addBaseFieldIndex().
    */
-  protected function removeBaseFieldIndex() {
+  protected function removeBaseFieldIndex(): void {
     $this->state->delete('entity_test_update.additional_field_index.entity_test_update.new_base_field');
   }
 
@@ -316,7 +328,7 @@ trait EntityDefinitionTestTrait {
    * @param bool $translatable
    *   (optional) Whether the field should be translatable. Defaults to FALSE.
    */
-  protected function addBundleField($type = 'string', $revisionable = FALSE, $translatable = FALSE) {
+  protected function addBundleField($type = 'string', $revisionable = FALSE, $translatable = FALSE): void {
     $definitions['new_bundle_field'] = FieldStorageDefinition::create($type)
       ->setName('new_bundle_field')
       ->setLabel(t('A new bundle field'))
@@ -330,14 +342,14 @@ trait EntityDefinitionTestTrait {
   /**
    * Modifies the new bundle field from 'string' to 'text'.
    */
-  protected function modifyBundleField() {
+  protected function modifyBundleField(): void {
     $this->addBundleField('text');
   }
 
   /**
    * Removes the new bundle field from the 'entity_test_update' entity type.
    */
-  protected function removeBundleField() {
+  protected function removeBundleField(): void {
     $this->state->delete('entity_test_update.additional_field_storage_definitions');
     $this->state->delete('entity_test_update.additional_bundle_field_definitions.test_bundle');
   }
@@ -347,7 +359,7 @@ trait EntityDefinitionTestTrait {
    *
    * @see \Drupal\entity_test\EntityTestStorageSchema::getEntitySchema()
    */
-  protected function addEntityIndex() {
+  protected function addEntityIndex(): void {
     $indexes = [
       'entity_test_update__new_index' => ['name', 'test_single_property'],
     ];
@@ -357,14 +369,14 @@ trait EntityDefinitionTestTrait {
   /**
    * Removes the index added in addEntityIndex().
    */
-  protected function removeEntityIndex() {
+  protected function removeEntityIndex(): void {
     $this->state->delete('entity_test_update.additional_entity_indexes');
   }
 
   /**
    * Renames the base table to 'entity_test_update_new'.
    */
-  protected function renameBaseTable() {
+  protected function renameBaseTable(): void {
     $entity_type = clone \Drupal::entityTypeManager()->getDefinition('entity_test_update');
 
     $entity_type->set('base_table', 'entity_test_update_new');
@@ -375,7 +387,7 @@ trait EntityDefinitionTestTrait {
   /**
    * Renames the data table to 'entity_test_update_data_new'.
    */
-  protected function renameDataTable() {
+  protected function renameDataTable(): void {
     $entity_type = clone \Drupal::entityTypeManager()->getDefinition('entity_test_update');
 
     $entity_type->set('data_table', 'entity_test_update_data_new');
@@ -386,7 +398,7 @@ trait EntityDefinitionTestTrait {
   /**
    * Renames the revision table to 'entity_test_update_revision_new'.
    */
-  protected function renameRevisionBaseTable() {
+  protected function renameRevisionBaseTable(): void {
     $entity_type = clone \Drupal::entityTypeManager()->getDefinition('entity_test_update');
 
     $entity_type->set('revision_table', 'entity_test_update_revision_new');
@@ -397,7 +409,7 @@ trait EntityDefinitionTestTrait {
   /**
    * Renames the revision data table to 'entity_test_update_revision_data_new'.
    */
-  protected function renameRevisionDataTable() {
+  protected function renameRevisionDataTable(): void {
     $entity_type = clone \Drupal::entityTypeManager()->getDefinition('entity_test_update');
 
     $entity_type->set('revision_data_table', 'entity_test_update_revision_data_new');
@@ -408,7 +420,7 @@ trait EntityDefinitionTestTrait {
   /**
    * Removes the entity type.
    */
-  protected function deleteEntityType() {
+  protected function deleteEntityType(): void {
     $this->state->set('entity_test_update.entity_type', 'null');
   }
 
@@ -462,7 +474,6 @@ trait EntityDefinitionTestTrait {
     $this->container->get('entity_type.manager')->clearCachedDefinitions();
     $this->container->get('entity_type.bundle.info')->clearCachedBundles();
     $this->container->get('entity_field.manager')->clearCachedFieldDefinitions();
-    $this->container->get('entity_type.repository')->clearCachedDefinitions();
 
     return $entity_type;
   }
