@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\taxonomy\Kernel\Views;
 
 use Drupal\field\Entity\FieldConfig;
@@ -22,10 +24,10 @@ class TaxonomyDefaultArgumentTest extends TaxonomyTestBase {
   public static $testViews = ['taxonomy_default_argument_test'];
 
   /**
-   * Init view with a request by provided url.
+   * Init view with a request by provided URL.
    *
    * @param string $request_url
-   *   The requested url.
+   *   The requested URL.
    * @param string $view_name
    *   The name of the view.
    *
@@ -54,15 +56,19 @@ class TaxonomyDefaultArgumentTest extends TaxonomyTestBase {
   /**
    * Tests the relationship.
    */
-  public function testNodePath() {
+  public function testNodePath(): void {
     $view = $this->initViewWithRequest($this->nodes[0]->toUrl()->toString());
 
     $expected = implode(',', [$this->term1->id(), $this->term2->id()]);
-    $this->assertEqual($expected, $view->argument['tid']->getDefaultArgument());
+    $this->assertEquals($expected, $view->argument['tid']->getDefaultArgument());
+    $this->assertEquals($this->nodes[0]->getCacheTags(), $view->argument['tid']->getPlugin('argument_default')->getCacheTags());
     $view->destroy();
   }
 
-  public function testNodePathWithViewSelection() {
+  /**
+   * Tests the entity reference field using a view for selection.
+   */
+  public function testNodePathWithViewSelection(): void {
     // Change the term entity reference field to use a view as selection plugin.
     \Drupal::service('module_installer')->install(['entity_reference_test']);
 
@@ -80,14 +86,19 @@ class TaxonomyDefaultArgumentTest extends TaxonomyTestBase {
     $view = $this->initViewWithRequest($this->nodes[0]->toUrl()->toString());
 
     $expected = implode(',', [$this->term1->id(), $this->term2->id()]);
-    $this->assertEqual($expected, $view->argument['tid']->getDefaultArgument());
+    $this->assertEquals($expected, $view->argument['tid']->getDefaultArgument());
+    $this->assertEquals($this->nodes[0]->getCacheTags(), $view->argument['tid']->getPlugin('argument_default')->getCacheTags());
   }
 
-  public function testTermPath() {
+  /**
+   * Tests the behavior of term ID argument when accessing a term path.
+   */
+  public function testTermPath(): void {
     $view = $this->initViewWithRequest($this->term1->toUrl()->toString());
 
     $expected = $this->term1->id();
-    $this->assertEqual($expected, $view->argument['tid']->getDefaultArgument());
+    $this->assertEquals($expected, $view->argument['tid']->getDefaultArgument());
+    $this->assertEmpty($view->argument['tid']->getPlugin('argument_default')->getCacheTags());
   }
 
 }
