@@ -29,7 +29,7 @@ class DayDate extends Date {
     $day = str_pad($data->{$this->name_alias}, 2, '0', STR_PAD_LEFT);
     // strtotime() respects server timezone, so we need to set the time fixed
     // as utc time
-    return $this->dateFormatter->format(strtotime("2005" . "05" . $day . " 00:00:00 UTC"), 'custom', $this->format, 'UTC');
+    return $this->dateFormatter->format(strtotime("200505" . $day . " 00:00:00 UTC"), 'custom', $this->format, 'UTC');
   }
 
   /**
@@ -37,9 +37,12 @@ class DayDate extends Date {
    */
   public function title() {
     $day = str_pad($this->argument, 2, '0', STR_PAD_LEFT);
-    return $this->dateFormatter->format(strtotime("2005" . "05" . $day . " 00:00:00 UTC"), 'custom', $this->format, 'UTC');
+    return $this->dateFormatter->format(strtotime("200505" . $day . " 00:00:00 UTC"), 'custom', $this->format, 'UTC');
   }
 
+  /**
+   * {@inheritdoc}
+   */
   public function summaryArgument($data) {
     // Make sure the argument contains leading zeroes.
     return str_pad($data->{$this->base_alias}, 2, '0', STR_PAD_LEFT);
