@@ -1,10 +1,15 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\views_test_data\Plugin\views\filter;
 
 use Drupal\views\Attribute\ViewsFilter;
 use Drupal\views\Plugin\views\filter\FilterPluginBase;
 
+/**
+ * Provides a test filter plugin with a custom cache context.
+ */
 #[ViewsFilter("views_test_test_cache_context")]
 class ViewsTestCacheContextFilter extends FilterPluginBase {
 
