@@ -4,6 +4,8 @@ declare(strict_types=1);
 
 namespace Drupal\KernelTests\Core\Entity;
 
+use Drupal\entity_test\EntityTestHelper;
+
 /**
  * @coversDefaultClass \Drupal\Core\Entity\EntityBundleListener
  *
@@ -12,11 +14,13 @@ namespace Drupal\KernelTests\Core\Entity;
 class EntityBundleListenerTest extends EntityKernelTestBase {
 
   /**
-   * @covers ::onBundleCreate
+   * Test bundle creation.
    *
    * Note: Installing the entity_schema_test module will mask the bug this test
    * was written to cover, as the field map cache is cleared manually by
    * \Drupal\Core\Field\FieldDefinitionListener::onFieldDefinitionCreate().
+   *
+   * @covers ::onBundleCreate
    */
   public function testOnBundleCreate(): void {
     $field_map = $this->container->get('entity_field.manager')->getFieldMap();
@@ -25,7 +29,7 @@ class EntityBundleListenerTest extends EntityKernelTestBase {
     ];
     $this->assertEquals($expected, $field_map['entity_test']['id']['bundles']);
 
-    entity_test_create_bundle('custom');
+    EntityTestHelper::createBundle('custom');
     $field_map = $this->container->get('entity_field.manager')->getFieldMap();
     $expected = [
       'entity_test' => 'entity_test',
