@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\KernelTests\Core\Entity;
 
 use Drupal\field\Entity\FieldConfig;
@@ -14,11 +16,9 @@ use Drupal\field\Entity\FieldStorageConfig;
 class EntityQueryAggregateTest extends EntityKernelTestBase {
 
   /**
-   * Modules to enable.
-   *
-   * @var array
+   * {@inheritdoc}
    */
-  protected static $modules = [];
+  protected static $modules = ['field_test'];
 
   /**
    * The entity_test storage to create the test entities.
@@ -34,6 +34,9 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
    */
   protected $queryResult;
 
+  /**
+   * {@inheritdoc}
+   */
   protected function setUp(): void {
     parent::setUp();
 
@@ -108,11 +111,12 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
   }
 
   /**
-   * Test aggregation support.
+   * Tests aggregation support.
    */
-  public function testAggregation() {
-    // Apply a simple groupby.
+  public function testAggregation(): void {
+    // Apply a simple group by.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->groupBy('user_id')
       ->execute();
 
@@ -132,17 +136,19 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
     // Apply a simple aggregation for different aggregation functions.
     foreach ($function_expected as $aggregation_function => $expected) {
       $query = $this->entityStorage->getAggregateQuery()
+        ->accessCheck(FALSE)
         ->aggregate('id', $aggregation_function);
       $this->queryResult = $query->execute();
       // We need to check that a character exists before and after the table,
       // column and alias identifiers. These would be the quote characters
       // specific for each database system.
-      $this->assertRegExp('/' . $aggregation_function . '\(.entity_test.\..id.\) AS .id_' . $aggregation_function . './', (string) $query, 'The argument to the aggregation function should be a quoted field.');
+      $this->assertMatchesRegularExpression('/' . $aggregation_function . '\(.*entity_test.\..id.\).* AS .id_' . $aggregation_function . './', (string) $query, 'The argument to the aggregation function should be a quoted field.');
       $this->assertEquals($expected, $this->queryResult);
     }
 
-    // Apply aggregation and groupby on the same query.
+    // Apply aggregation and group by on the same query.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->aggregate('id', 'COUNT')
       ->groupBy('user_id')
       ->execute();
@@ -154,6 +160,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
 
     // Apply aggregation and a condition which matches.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->aggregate('id', 'COUNT')
       ->groupBy('id')
       ->conditionAggregate('id', 'COUNT', 8)
@@ -162,6 +169,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
 
     // Don't call aggregate to test the implicit aggregate call.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->groupBy('id')
       ->conditionAggregate('id', 'COUNT', 8)
       ->execute();
@@ -169,24 +177,27 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
 
     // Apply aggregation and a condition which matches.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->aggregate('id', 'count')
       ->groupBy('id')
       ->conditionAggregate('id', 'COUNT', 6)
       ->execute();
     $this->assertResults([['id_count' => 6]]);
 
-    // Apply aggregation, a groupby and a condition which matches partially via
+    // Apply aggregation, a group by and a condition which matches partially via
     // the operator '='.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->aggregate('id', 'count')
       ->conditionAggregate('id', 'count', 2)
       ->groupBy('user_id')
       ->execute();
     $this->assertResults([['id_count' => 2, 'user_id' => 3]]);
 
-    // Apply aggregation, a groupby and a condition which matches partially via
+    // Apply aggregation, a group by and a condition which matches partially via
     // the operator '>'.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->aggregate('id', 'count')
       ->conditionAggregate('id', 'COUNT', 1, '>')
       ->groupBy('user_id')
@@ -199,6 +210,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
     // Apply aggregation and a sort. This might not be useful, but have a proper
     // test coverage.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->aggregate('id', 'COUNT')
       ->sortAggregate('id', 'COUNT')
       ->execute();
@@ -206,12 +218,14 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
 
     // Don't call aggregate to test the implicit aggregate call.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->sortAggregate('id', 'COUNT')
       ->execute();
     $this->assertSortedResults([['id_count' => 6]]);
 
-    // Apply aggregation, groupby and a sort descending.
+    // Apply aggregation, group by and a sort descending.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->aggregate('id', 'COUNT')
       ->groupBy('user_id')
       ->sortAggregate('id', 'COUNT', 'DESC')
@@ -222,8 +236,9 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
       ['user_id' => 1, 'id_count' => 1],
     ]);
 
-    // Apply aggregation, groupby and a sort ascending.
+    // Apply aggregation, group by and a sort ascending.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->aggregate('id', 'COUNT')
       ->groupBy('user_id')
       ->sortAggregate('id', 'COUNT', 'ASC')
@@ -234,9 +249,10 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
       ['user_id' => 2, 'id_count' => 3],
     ]);
 
-    // Apply aggregation, groupby, an aggregation condition and a sort with the
+    // Apply aggregation, group by, an aggregation condition and a sort with the
     // operator '='.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->aggregate('id', 'COUNT')
       ->groupBy('user_id')
       ->sortAggregate('id', 'COUNT')
@@ -244,9 +260,10 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
       ->execute();
     $this->assertSortedResults([['id_count' => 2, 'user_id' => 3]]);
 
-    // Apply aggregation, groupby, an aggregation condition and a sort with the
+    // Apply aggregation, group by, an aggregation condition and a sort with the
     // operator '<' and order ASC.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->aggregate('id', 'COUNT')
       ->groupBy('user_id')
       ->sortAggregate('id', 'COUNT', 'ASC')
@@ -257,9 +274,10 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
       ['id_count' => 2, 'user_id' => 3],
     ]);
 
-    // Apply aggregation, groupby, an aggregation condition and a sort with the
+    // Apply aggregation, group by, an aggregation condition and a sort with the
     // operator '<' and order DESC.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->aggregate('id', 'COUNT')
       ->groupBy('user_id')
       ->sortAggregate('id', 'COUNT', 'DESC')
@@ -270,10 +288,11 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
       ['id_count' => 1, 'user_id' => 1],
     ]);
 
-    // Test aggregation/groupby support for fieldapi fields.
+    // Test aggregation/group by support for fieldapi fields.
 
     // Just group by a fieldapi field.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->groupBy('field_test_1')
       ->execute();
     $this->assertResults([
@@ -284,6 +303,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
 
     // Group by a fieldapi field and aggregate a normal property.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->aggregate('user_id', 'COUNT')
       ->groupBy('field_test_1')
       ->execute();
@@ -296,6 +316,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
 
     // Group by a normal property and aggregate a fieldapi field.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->aggregate('field_test_1', 'COUNT')
       ->groupBy('user_id')
       ->execute();
@@ -307,6 +328,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
     ]);
 
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->aggregate('field_test_1', 'SUM')
       ->groupBy('user_id')
       ->execute();
@@ -318,6 +340,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
 
     // Aggregate by two different fieldapi fields.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->aggregate('field_test_1', 'SUM')
       ->aggregate('field_test_2', 'SUM')
       ->groupBy('user_id')
@@ -330,6 +353,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
 
     // This time aggregate the same field twice.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->aggregate('field_test_1', 'SUM')
       ->aggregate('field_test_1', 'COUNT')
       ->groupBy('user_id')
@@ -342,6 +366,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
 
     // Group by and aggregate by a fieldapi field.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->groupBy('field_test_1')
       ->aggregate('field_test_2', 'COUNT')
       ->execute();
@@ -354,6 +379,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
     // Group by and aggregate by a fieldapi field and use multiple aggregate
     // functions.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->groupBy('field_test_1')
       ->aggregate('field_test_2', 'COUNT')
       ->aggregate('field_test_2', 'SUM')
@@ -367,6 +393,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
     // Apply an aggregate condition for a fieldapi field and group by a simple
     // property.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->conditionAggregate('field_test_1', 'COUNT', 3)
       ->groupBy('user_id')
       ->execute();
@@ -376,6 +403,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
     ]);
 
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->aggregate('field_test_1', 'SUM')
       ->conditionAggregate('field_test_1', 'COUNT', 2, '>')
       ->groupBy('user_id')
@@ -388,6 +416,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
     // Apply an aggregate condition for a simple property and a group by a
     // fieldapi field.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->conditionAggregate('user_id', 'COUNT', 2)
       ->groupBy('field_test_1')
       ->execute();
@@ -396,6 +425,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
     ]);
 
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->conditionAggregate('user_id', 'COUNT', 2, '>')
       ->groupBy('field_test_1')
       ->execute();
@@ -406,6 +436,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
 
     // Apply an aggregate condition and a group by fieldapi fields.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->groupBy('field_test_1')
       ->conditionAggregate('field_test_2', 'COUNT', 2)
       ->execute();
@@ -413,6 +444,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
       ['field_test_1' => 1, 'field_test_2_count' => 2],
     ]);
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->groupBy('field_test_1')
       ->conditionAggregate('field_test_2', 'COUNT', 2, '>')
       ->execute();
@@ -424,6 +456,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
     // Apply an aggregate condition and a group by fieldapi fields with multiple
     // conditions via AND.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->groupBy('field_test_1')
       ->conditionAggregate('field_test_2', 'COUNT', 2)
       ->conditionAggregate('field_test_2', 'SUM', 8)
@@ -433,6 +466,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
     // Apply an aggregate condition and a group by fieldapi fields with multiple
     // conditions via OR.
     $this->queryResult = $this->entityStorage->getAggregateQuery('OR')
+      ->accessCheck(FALSE)
       ->groupBy('field_test_1')
       ->conditionAggregate('field_test_2', 'COUNT', 2)
       ->conditionAggregate('field_test_2', 'SUM', 8)
@@ -443,8 +477,9 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
     ]);
 
     // Group by a normal property and aggregate a fieldapi field and sort by the
-    // groupby field.
+    // group by field.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->aggregate('field_test_1', 'COUNT')
       ->groupBy('user_id')
       ->sort('user_id', 'DESC')
@@ -456,6 +491,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
     ]);
 
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->aggregate('field_test_1', 'COUNT')
       ->groupBy('user_id')
       ->sort('user_id', 'ASC')
@@ -467,6 +503,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
     ]);
 
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->conditionAggregate('field_test_1', 'COUNT', 2, '>')
       ->groupBy('user_id')
       ->sort('user_id', 'ASC')
@@ -479,6 +516,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
     // Group by a normal property, aggregate a fieldapi field, and sort by the
     // aggregated field.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->sortAggregate('field_test_1', 'COUNT', 'DESC')
       ->groupBy('user_id')
       ->execute();
@@ -489,6 +527,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
     ]);
 
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->sortAggregate('field_test_1', 'COUNT', 'ASC')
       ->groupBy('user_id')
       ->execute();
@@ -498,8 +537,9 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
       ['user_id' => 2, 'field_test_1_count' => 3],
     ]);
 
-    // Group by and aggregate by fieldapi field, and sort by the groupby field.
+    // Group by and aggregate by fieldapi field, and sort by the group by field.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->groupBy('field_test_1')
       ->aggregate('field_test_2', 'COUNT')
       ->sort('field_test_1', 'ASC')
@@ -511,6 +551,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
     ]);
 
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->groupBy('field_test_1')
       ->aggregate('field_test_2', 'COUNT')
       ->sort('field_test_1', 'DESC')
@@ -524,6 +565,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
     // Group by and aggregate by Field API field, and sort by the aggregated
     // field.
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->groupBy('field_test_1')
       ->sortAggregate('field_test_2', 'COUNT', 'DESC')
       ->execute();
@@ -534,6 +576,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
     ]);
 
     $this->queryResult = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->groupBy('field_test_1')
       ->sortAggregate('field_test_2', 'COUNT', 'ASC')
       ->execute();
@@ -548,8 +591,9 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
   /**
    * Tests preparing a query and executing twice.
    */
-  public function testRepeatedExecution() {
+  public function testRepeatedExecution(): void {
     $query = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
       ->groupBy('user_id');
 
     $this->queryResult = $query->execute();
@@ -577,13 +621,56 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
     ]);
   }
 
+  /**
+   * Tests that entity query alter hooks are invoked for aggregate queries.
+   *
+   * Hook functions in field_test.module add additional conditions to the query
+   * removing entities with specific ids.
+   */
+  public function testAlterHook(): void {
+    $basicQuery = $this->entityStorage->getAggregateQuery()
+      ->accessCheck(FALSE)
+      ->groupBy('id');
+
+    // Verify assumptions about the unaltered result.
+    $query = clone $basicQuery;
+    $this->queryResult = $query->execute();
+    $this->assertResults([
+      ['id' => 1],
+      ['id' => 2],
+      ['id' => 3],
+      ['id' => 4],
+      ['id' => 5],
+      ['id' => 6],
+    ]);
+
+    // field_test_entity_query_alter() removes the entity with id '5'.
+    $query = clone $basicQuery;
+    $this->queryResult = $query
+      // Add a tag that no hook function matches.
+      ->addTag('entity_query_alter_hook_test')
+      ->execute();
+    $this->assertResults([
+      ['id' => 1],
+      ['id' => 2],
+      ['id' => 3],
+      ['id' => 4],
+      ['id' => 6],
+    ]);
+  }
+
   /**
    * Asserts the results as expected regardless of order between and in rows.
    *
    * @param array $expected
    *   An array of the expected results.
+   * @param bool $sorted
+   *   (optiOnal) Whether the array keys of the expected are sorted, defaults to
+   *   FALSE.
+   *
+   * @internal
    */
-  protected function assertResults($expected, $sorted = FALSE) {
+  protected function assertResults(array $expected, bool $sorted = FALSE): void {
     $found = TRUE;
     $expected_keys = array_keys($expected);
     foreach ($this->queryResult as $key => $row) {
@@ -597,7 +684,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
       $found = FALSE;
       break;
     }
-    return $this->assertTrue($found, strtr('!expected expected, !found found', ['!expected' => print_r($expected, TRUE), '!found' => print_r($this->queryResult, TRUE)]));
+    $this->assertTrue($found, strtr('!expected expected, !found found', ['!expected' => print_r($expected, TRUE), '!found' => print_r($this->queryResult, TRUE)]));
   }
 
   /**
@@ -605,9 +692,11 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
    *
    * @param array $expected
    *   An array of the expected results.
+   *
+   * @internal
    */
-  protected function assertSortedResults($expected) {
-    return $this->assertResults($expected, TRUE);
+  protected function assertSortedResults(array $expected): void {
+    $this->assertResults($expected, TRUE);
   }
 
 }
