@@ -18,6 +18,10 @@ class UrlHelperTest extends TestCase {
    * Provides test data for testBuildQuery().
    *
    * @return array
+   *   An array of test cases. Each test case contains:
+   *   - array $query: An array of query parameters.
+   *   - string $expected: The expected query string.
+   *   - string $message: The assertion message.
    */
   public static function providerTestBuildQuery() {
     return [
@@ -32,15 +36,15 @@ class UrlHelperTest extends TestCase {
   /**
    * Tests query building.
    *
-   * @dataProvider providerTestBuildQuery
-   * @covers ::buildQuery
-   *
    * @param array $query
    *   The array of query parameters.
    * @param string $expected
    *   The expected query string.
    * @param string $message
    *   The assertion message.
+   *
+   * @dataProvider providerTestBuildQuery
+   * @covers ::buildQuery
    */
   public function testBuildQuery($query, $expected, $message): void {
     $this->assertEquals(UrlHelper::buildQuery($query), $expected, $message);
@@ -50,6 +54,7 @@ class UrlHelperTest extends TestCase {
    * Data provider for testValidAbsolute().
    *
    * @return array
+   *   An array of valid absolute URLs, with various schemes applied.
    */
   public static function providerTestValidAbsoluteData(): array {
     $urls = [
@@ -81,13 +86,13 @@ class UrlHelperTest extends TestCase {
   /**
    * Tests valid absolute URLs.
    *
-   * @dataProvider providerTestValidAbsoluteData
-   * @covers ::isValid
-   *
    * @param string $url
    *   The URL to test.
    * @param string $scheme
    *   The scheme to test.
+   *
+   * @dataProvider providerTestValidAbsoluteData
+   * @covers ::isValid
    */
   public function testValidAbsolute(string $url, string $scheme): void {
     $test_url = $scheme . '://' . $url;
@@ -99,6 +104,7 @@ class UrlHelperTest extends TestCase {
    * Provides data for testInvalidAbsolute().
    *
    * @return array
+   *   An array of invalid absolute URLs.
    */
   public static function providerTestInvalidAbsolute(): array {
     $data = [
@@ -136,13 +142,13 @@ class UrlHelperTest extends TestCase {
   /**
    * Tests invalid absolute URLs.
    *
-   * @dataProvider providerTestInvalidAbsolute
-   * @covers ::isValid
-   *
    * @param string $url
    *   The URL to test.
    * @param string $scheme
    *   The scheme to test.
+   *
+   * @dataProvider providerTestInvalidAbsolute
+   * @covers ::isValid
    */
   public function testInvalidAbsolute(string $url, string $scheme): void {
     $test_url = $scheme . '://' . $url;
@@ -154,6 +160,7 @@ class UrlHelperTest extends TestCase {
    * Provides data for testValidRelative().
    *
    * @return array
+   *   An array of valid relative URLs.
    */
   public static function providerTestValidRelativeData(): array {
     $data = [
@@ -170,13 +177,13 @@ class UrlHelperTest extends TestCase {
   /**
    * Tests valid relative URLs.
    *
-   * @dataProvider providerTestValidRelativeData
-   * @covers ::isValid
-   *
    * @param string $url
    *   The URL to test.
    * @param string $prefix
    *   The prefix to test.
+   *
+   * @dataProvider providerTestValidRelativeData
+   * @covers ::isValid
    */
   public function testValidRelative(string $url, string $prefix): void {
     $test_url = $prefix . $url;
@@ -188,6 +195,7 @@ class UrlHelperTest extends TestCase {
    * Provides data for testInvalidRelative().
    *
    * @return array
+   *   An array of invalid relative URLs.
    */
   public static function providerTestInvalidRelativeData(): array {
     $data = [
@@ -202,13 +210,13 @@ class UrlHelperTest extends TestCase {
   /**
    * Tests invalid relative URLs.
    *
-   * @dataProvider providerTestInvalidRelativeData
-   * @covers ::isValid
-   *
    * @param string $url
    *   The URL to test.
    * @param string $prefix
    *   The prefix to test.
+   *
+   * @dataProvider providerTestInvalidRelativeData
+   * @covers ::isValid
    */
   public function testInvalidRelative(string $url, string $prefix): void {
     $test_url = $prefix . $url;
@@ -219,9 +227,6 @@ class UrlHelperTest extends TestCase {
   /**
    * Tests query filtering.
    *
-   * @dataProvider providerTestFilterQueryParameters
-   * @covers ::filterQueryParameters
-   *
    * @param array $query
    *   The array of query parameters.
    * @param array $exclude
@@ -229,6 +234,9 @@ class UrlHelperTest extends TestCase {
    *   nested items.
    * @param array $expected
    *   An array containing query parameters.
+   *
+   * @dataProvider providerTestFilterQueryParameters
+   * @covers ::filterQueryParameters
    */
   public function testFilterQueryParameters($query, $exclude, $expected): void {
     $filtered = UrlHelper::filterQueryParameters($query, $exclude);
@@ -239,8 +247,9 @@ class UrlHelperTest extends TestCase {
    * Provides data to self::testFilterQueryParameters().
    *
    * @return array
+   *   An array of test cases with query parameters, exclusions, and expected results.
    */
-  public static function providerTestFilterQueryParameters() {
+  public static function providerTestFilterQueryParameters(): array {
     return [
       // Test without an exclude filter.
       [
@@ -260,13 +269,13 @@ class UrlHelperTest extends TestCase {
   /**
    * Tests URL parsing.
    *
-   * @dataProvider providerTestParse
-   * @covers ::parse
-   *
    * @param string $url
    *   URL to test.
    * @param array $expected
    *   Associative array with expected parameters.
+   *
+   * @dataProvider providerTestParse
+   * @covers ::parse
    */
   public function testParse($url, $expected): void {
     $parsed = UrlHelper::parse($url);
@@ -277,6 +286,7 @@ class UrlHelperTest extends TestCase {
    * Provides data for self::testParse().
    *
    * @return array
+   *   An array of test cases with URLs and expected parsed results.
    */
   public static function providerTestParse() {
     return [
@@ -376,19 +386,27 @@ class UrlHelperTest extends TestCase {
           'fragment' => 'footer',
         ],
       ],
+      'Malformed URL should not trigger PHP warnings' => [
+        "#/://#",
+        [
+          'path' => NULL,
+          'query' => [],
+          'fragment' => "/://#",
+        ],
+      ],
     ];
   }
 
   /**
    * Tests path encoding.
    *
-   * @dataProvider providerTestEncodePath
-   * @covers ::encodePath
-   *
    * @param string $path
    *   A path to encode.
    * @param string $expected
    *   The expected encoded path.
+   *
+   * @dataProvider providerTestEncodePath
+   * @covers ::encodePath
    */
   public function testEncodePath($path, $expected): void {
     $encoded = UrlHelper::encodePath($path);
@@ -399,6 +417,7 @@ class UrlHelperTest extends TestCase {
    * Provides data for self::testEncodePath().
    *
    * @return array
+   *   An array of test cases with unencoded paths and expected encoded paths.
    */
   public static function providerTestEncodePath() {
     return [
@@ -410,13 +429,13 @@ class UrlHelperTest extends TestCase {
   /**
    * Tests external versus internal paths.
    *
-   * @dataProvider providerTestIsExternal
-   * @covers ::isExternal
-   *
    * @param string $path
    *   URL or path to test.
    * @param bool $expected
    *   Expected result.
+   *
+   * @dataProvider providerTestIsExternal
+   * @covers ::isExternal
    */
   public function testIsExternal($path, $expected): void {
     $isExternal = UrlHelper::isExternal($path);
@@ -427,6 +446,7 @@ class UrlHelperTest extends TestCase {
    * Provides data for self::testIsExternal().
    *
    * @return array
+   *   An array of test cases with paths and their expected external status.
    */
   public static function providerTestIsExternal() {
     return [
@@ -467,10 +487,6 @@ class UrlHelperTest extends TestCase {
   /**
    * Tests bad protocol filtering and escaping.
    *
-   * @dataProvider providerTestFilterBadProtocol
-   * @covers ::setAllowedProtocols
-   * @covers ::filterBadProtocol
-   *
    * @param string $uri
    *   Protocol URI.
    * @param string $expected
@@ -478,6 +494,9 @@ class UrlHelperTest extends TestCase {
    * @param array $protocols
    *   Protocols to allow.
    *
+   * @dataProvider providerTestFilterBadProtocol
+   * @covers ::setAllowedProtocols
+   * @covers ::filterBadProtocol
    * @runInSeparateProcess
    */
   public function testFilterBadProtocol($uri, $expected, $protocols): void {
@@ -492,6 +511,7 @@ class UrlHelperTest extends TestCase {
    * Provides data for self::testTestFilterBadProtocol().
    *
    * @return array
+   *   An array of test cases with URIs, expected filtered results, and allowed protocols.
    */
   public static function providerTestFilterBadProtocol() {
     return [
@@ -508,10 +528,6 @@ class UrlHelperTest extends TestCase {
   /**
    * Tests dangerous URL protocol filtering.
    *
-   * @dataProvider providerTestStripDangerousProtocols
-   * @covers ::setAllowedProtocols
-   * @covers ::stripDangerousProtocols
-   *
    * @param string $uri
    *   Protocol URI.
    * @param string $expected
@@ -519,6 +535,9 @@ class UrlHelperTest extends TestCase {
    * @param array $protocols
    *   Protocols to allow.
    *
+   * @dataProvider providerTestStripDangerousProtocols
+   * @covers ::setAllowedProtocols
+   * @covers ::stripDangerousProtocols
    * @runInSeparateProcess
    */
   public function testStripDangerousProtocols($uri, $expected, $protocols): void {
@@ -531,6 +550,7 @@ class UrlHelperTest extends TestCase {
    * Provides data for self::testStripDangerousProtocols().
    *
    * @return array
+   *   An array of test cases with URIs, expected stripped results, and allowed protocols.
    */
   public static function providerTestStripDangerousProtocols() {
     return [
