@@ -132,26 +132,41 @@ trait PerformanceTestTrait {
       $cache_tag_is_valid_count = 0;
       $cache_tag_invalidation_count = 0;
       $cache_tag_checksum_count = 0;
+      $cache_tag_lookup_query_args = [];
       foreach ($performance_test_data['database_events'] as $event) {
+        $normalized_query = static::normalizeQuery($event->queryString, $this->databasePrefix);
+
         // Don't log queries from the database cache backend because they're
         // logged separately as cache operations.
         if (!static::isDatabaseCache($event)) {
-          // Make the query easier to read and log it.
-          static::logQuery(
-            $performance_data,
-            str_replace([$this->databasePrefix, "\r\n", "\r", "\n"], ['', ' ', ' ', ' '], $event->queryString),
-            $event->args
-          );
+          static::logQuery($performance_data, $normalized_query, $event->args);
+        }
+        // Keep track of cache tag lookup queries.
+        elseif (str_starts_with($normalized_query, 'SELECT "tag", "invalidations" FROM "cachetags"')) {
+          $cache_tag_lookup_query_args[] = array_values($event->args);
         }
       }
+      $cache_operations = [];
       foreach ($performance_test_data['cache_operations'] as $operation) {
         if (in_array($operation['operation'], ['get', 'getMultiple'], TRUE)) {
+          if (!isset($cache_operations['get'][$operation['bin']])) {
+            $cache_operations['get'][$operation['bin']] = [];
+          }
+          $cache_operations['get'][$operation['bin']][] = $operation['cids'];
           $cache_get_count++;
         }
         elseif (in_array($operation['operation'], ['set', 'setMultiple'], TRUE)) {
+          if (!isset($cache_operations['get'][$operation['bin']])) {
+            $cache_operations['set'][$operation['bin']] = [];
+          }
+          $cache_operations['set'][$operation['bin']][] = $operation['cids'];
           $cache_set_count++;
         }
         elseif (in_array($operation['operation'], ['delete', 'deleteMultiple'], TRUE)) {
+          if (!isset($cache_operations['delete'][$operation['bin']])) {
+            $cache_operations['delete'][$operation['bin']] = [];
+          }
+          $cache_operations['delete'][$operation['bin']][] = $operation['cids'];
           $cache_delete_count++;
         }
       }
@@ -168,6 +183,8 @@ trait PerformanceTestTrait {
       $performance_data->setCacheTagChecksumCount($cache_tag_checksum_count);
       $performance_data->setCacheTagIsValidCount($cache_tag_is_valid_count);
       $performance_data->setCacheTagInvalidationCount($cache_tag_invalidation_count);
+      $performance_data->setCacheOperations($cache_operations);
+      $performance_data->setCacheTagGroupedLookups($cache_tag_lookup_query_args);
     }
 
     return $performance_data;
@@ -282,7 +299,8 @@ trait PerformanceTestTrait {
    * @todo https://www.drupal.org/project/drupal/issues/3379757
    *
    * @param string|null $service_name
-   *   An optional human readable identifier so that traces can be grouped together.
+   *   An optional human readable identifier so that traces can be grouped
+   *   together.
    *
    * @return \Drupal\Tests\PerformanceData
    *   An instance of the performance data value object.
@@ -375,7 +393,7 @@ trait PerformanceTestTrait {
     // 'encodedDataLength' for network requests, however in the case that the
     // file has already been requested by the browser, this will be the length
     // of a HEAD response for 304 not modified or similar. Additionally, core's
-    // aggregation adds the basepath to CSS aggregates, resulting in slightly
+    // aggregation adds the base path to CSS aggregates, resulting in slightly
     // different file sizes depending on whether tests run in a subdirectory or
     // not.
     foreach ($stylesheet_urls as $url) {
@@ -386,7 +404,7 @@ trait PerformanceTestTrait {
       }
       else {
         $filename = str_replace($GLOBALS['base_path'], '', parse_url($url, PHP_URL_PATH));
-        // Strip the basepath from the contents of the file so that tests
+        // Strip the base path from the contents of the file so that tests
         // running in a subdirectory get the same results.
         $stylesheet_bytes += strlen(str_replace($GLOBALS['base_path'], '/', file_get_contents($filename)));
       }
@@ -471,7 +489,7 @@ trait PerformanceTestTrait {
       ResourceAttributes::SERVICE_NAME => $service_name,
       ResourceAttributes::SERVICE_INSTANCE_ID => 1,
       ResourceAttributes::SERVICE_VERSION => \Drupal::VERSION,
-      ResourceAttributes::DEPLOYMENT_ENVIRONMENT => 'local',
+      ResourceAttributes::DEPLOYMENT_ENVIRONMENT_NAME => 'local',
     ])));
 
     $otel_collector_headers = getenv('OTEL_COLLECTOR_HEADERS') ?: [];
@@ -503,7 +521,7 @@ trait PerformanceTestTrait {
       $collection = \Drupal::keyValue('performance_test');
       $performance_test_data = $collection->get('performance_test_data');
       $query_events = $performance_test_data['database_events'] ?? [];
-      foreach ($query_events as $key => $event) {
+      foreach ($query_events as $event) {
         if (static::isDatabaseCache($event)) {
           continue;
         }
@@ -590,16 +608,22 @@ trait PerformanceTestTrait {
    *   Maximum value.
    * @param int $actual
    *   The number to assert against.
+   * @param string $message
+   *   The message to display.
    *
    * @return void
+   *   No return value.
    *
    * @throws \PHPUnit\Framework\ExpectationFailedException
    */
-  protected function assertCountBetween(int $min, int $max, int $actual) {
+  protected function assertCountBetween(int $min, int $max, int $actual, string $message = '') {
+    if (!empty($message)) {
+      $message .= " ";
+    }
     static::assertThat(
       $actual,
       static::logicalAnd(static::greaterThanOrEqual($min), static::lessThanOrEqual($max)),
-      "$actual is greater or equal to $min and is smaller or equal to $max",
+      "$message$actual is greater or equal to $min and is smaller or equal to $max",
     );
   }
 
@@ -621,4 +645,78 @@ trait PerformanceTestTrait {
     return FALSE;
   }
 
+  /**
+   * Assert metrics from a performance data value object.
+   *
+   * @param array $expected
+   *   The expected metrics.
+   * @param \Drupal\Tests\PerformanceData $performance_data
+   *   An instance of the performance data value object.
+   *
+   * @return void
+   *   No return value.
+   */
+  protected function assertMetrics(
+    array $expected,
+    PerformanceData $performance_data,
+  ): void {
+    // Allow those metrics to have a range of +/- 500 bytes, so small changes
+    // are not significant enough to break tests.
+    $assertRange = [
+      'ScriptBytes',
+      'StylesheetBytes',
+    ];
+    $values = [];
+    foreach ($expected as $name => $metric) {
+      if (in_array($name, $assertRange)) {
+        $this->assertCountBetween($metric - 500, $metric + 500, $performance_data->{"get$name"}(), "Asserting $name");
+        unset($expected[$name]);
+      }
+      else {
+        $values[$name] = $performance_data->{"get$name"}();
+      }
+    }
+    $this->assertSame($expected, $values);
+
+  }
+
+  /**
+   * Get metrics from a performance data value object.
+   *
+   * @param \Drupal\Tests\PerformanceData $performance_data
+   *   An instance of the performance data value object.
+   *
+   * @return array
+   *   An array of metrics.
+   */
+  protected function getMetrics(PerformanceData $performance_data): array {
+    return [
+      'StylesheetCount' => $performance_data->getStylesheetCount(),
+      'ScriptCount' => $performance_data->getScriptCount(),
+      'StylesheetBytes' => $performance_data->getStylesheetBytes(),
+      'ScriptBytes' => $performance_data->getScriptBytes(),
+      'QueryCount' => $performance_data->getQueryCount(),
+      'CacheGetCount' => $performance_data->getCacheGetCount(),
+      'CacheSetCount' => $performance_data->getCacheSetCount(),
+      'CacheDeleteCount' => $performance_data->getCacheDeleteCount(),
+      'CacheTagLookupQueryCount' => $performance_data->getCacheTagLookupQueryCount(),
+      'CacheTagInvalidationCount' => $performance_data->getCacheTagInvalidationCount(),
+    ];
+  }
+
+  /**
+   * Normalizes a query by removing the database prefix and newlines.
+   *
+   * @param string $query_string
+   *   The query string to normalize.
+   * @param string $database_prefix
+   *   The database prefix to remove from the query.
+   *
+   * @return string
+   *   The normalized query string.
+   */
+  protected static function normalizeQuery(string $query_string, string $database_prefix): string {
+    return str_replace([$database_prefix, "\r\n", "\r", "\n"], ['', ' ', ' ', ' '], $query_string);
+  }
+
 }
